#include "colors.inc"
#include "shapes.inc"
#include "textures.inc"
//#include "stones.inc"
#include "chars.inc"

/******************************************\

 Render this animation from clock=5 to 665,
 for around 150 seconds of animation.
 The MOD sound file used if PSYDANCE.MOD (2'39)
 For a single image rendering, use clock=40

 The animation rendering in 320x240x12fps took
 17 hours on a Pentium 180MHz. (50MB CinePak AVI)

 Original script by Olivier Jacques.
 Animation by Olivier Lapicque.
 Render32 by Olivier Lapicque and Jerome Hubert

\******************************************/

#max_trace_level 3

#declare CLOCK_TO_SECS		= (((clock-5)*159)/660)

#declare CLOCK_LOGO_START	= ((148*660)/159+4)


#if clock > 40
#declare LOGO_HEIGHT = 10
#else
#declare LOGO_HEIGHT = (clock-30)
#endif


#if clock < CLOCK_LOGO_START
#declare AMBIENT = 1
#else
#declare AMBIENT = exp(-(clock-CLOCK_LOGO_START)/20)
#endif

#declare LIGHTCOLOR = <AMBIENT, AMBIENT, AMBIENT>


camera {
#if clock >= CLOCK_LOGO_START
  location <-11, 9, 100>
#elif clock > 45
  location <sin((clock-45)/10)*(47+clock/18), 9+clock/13, (47+clock/18)*cos((clock-45)/9)>
#else
  location  <0, 9, 50>
#endif
  direction <0, 0, -1>
  up        <0, 1, 0>
  right     <1.33333, 0, 0>

#if clock < CLOCK_LOGO_START
  look_at <-6, 9, 6>
#else
  look_at <-11, 9, 6>
#endif
}

// Sky sphere
object {
  sphere { <0, 0, 0> 2.5 inverse} // une boule que l'on inverse
  // 1re texture: dgrad sur l'axe vertical
  texture {
    pigment {
    gradient y
    color_map {
      [0.0 0.2 color red 0.6 green 0.1 blue 0.4 alpha 0
	       color red 0.7 green 0.2 blue 0.3 alpha 0]
      [0.2 0.6 color red 0.7 green 0.2 blue 0.3 alpha 0
	       color red 0.9 green 0.4 blue 0.4 alpha 0]
      [0.6 0.8 color red 0.9 green 0.4 blue 0.4 alpha 0
	       color red 0.7 green 0.2 blue 0.6 alpha 0]
      [0.8 1.0 color red 0.7 green 0.2 blue 0.6 alpha 0
	       color red 0.6 green 0.1 blue 0.4 alpha 0]
      }
    }
	finish {
	  ambient 0.3*AMBIENT
	  diffuse 0
	}
  }
  // 2me texture superpose: perturbations plus ou moins opaques
  texture {
    pigment {
    bozo
    turbulence 0.6
    color_map {
      [0.0 0.4 color red 0.5 green 0.5 blue 1.0 alpha 0
	       color red 0.6 green 0.6 blue 1.0 alpha 0.7]
      [0.4 0.8 color red 0.6 green 0.6 blue 1.0 alpha 0.7
	       color red 1.0 green 1.0 blue 1.0 alpha 0.4]
      [0.8 1.0 color red 1.0 green 1.0 blue 1.0 alpha 0.4
	       color red 0.5 green 0.5 blue 0.5 alpha 0.2]
      }
	phase clock/200
    }
    finish {
      diffuse 0
      ambient 0.3*AMBIENT
    }
	rotate <clock/20, clock/20, clock/20>
  }
  // agrandissement de notre environnement (objet ET textures)
  scale <5000, 5000, 5000>
  no_shadow
}

light_source { <-150, 100, 60> color LIGHTCOLOR }
//light_source { <20, 10, 200>   color White }
light_source { <-60, 100, 200> color LIGHTCOLOR }

// Logo EFREI
union {   
    difference {
      object { Disk_Z scale <5, 5, 1> }
      box { <-3, -4.5, -1.1> <-2.7, 4.5, 1.1> }
      box { <-1, -5.5, -1.1> <-0.8, 5.5, 1.1> }
      box { <-1.9, -5, -1.1> <-0.8, -3, 1.1> }
      // enleve le R
      box { <0, -5.5, -1.1> <1.8, 5.5, 1.1> }
      // enleve espace entre E et I
      box { <3.6, -4, -1.1> <4, 4, 1.1> }
      object { Disk_Z scale <4.2, 4.2, 1.1> }
    }
    box { <-4.5, -0.4, -1> <-3.0, 0.4, 1> }
    box { <-2.0, -0.4, -1> <-1.0, 0.4, 1> }
    box { <-2.7, -4.0, -1> <-1.9, 4.0, 1> }
    //Barre du R
    box { <-0.8, -4.6, -1> <0, 4.4, 1> }  
    //E
    box { <1.8, -4, -1> <2.6, 4, 1>}
    box { <2.5, -0.4, -1> <3.6, 0.4, 1> }
    //I
    difference {
      object { Disk_Z scale <1.8, 2.6, 1> }
      object { Disk_Z scale <1, 1.8, 1.1> }
      box { <-4, -6, -1.1> <0.0, 6, 1.1> }
      translate <-0.2, 2.4, 0>  //0.8
    }   
    box {<-0.8, -5, -1> <0, 0, 1> rotate <0, 0, 15> translate <0.5, 0.2, 0>}    

  texture { //logo
    //  Grnt29
    // Stone15 scale <10 10 10>
    // scale <2 4 1>
    // translate <0 -6 0>
    finish { reflection 0.7 diffuse 0.333 ambient 0.1*AMBIENT }
    pigment { color red 0.333 green 1.0 blue 0.666 }
  }

  // Pas de grosse diffrence avec les Auto Bounding Boxes, mais bon...
  bounded_by { box {<-6, -6, -1.2> <6, 6, 1.2>} }

  rotate <clock/5+2, clock*5-180, clock/10-1.5>
  translate <-6, 2, 6>
  scale <2, 2, 2>
  translate <0, LOGO_HEIGHT, 0>
}    


object {
  sphere { <0, 0, 0> 80 }
  pigment { color Orange }
  finish { reflection 0.6 ambient 0.1*AMBIENT }
  translate <300,200,-1000>
}


// Define the ocean surface 
object {
   plane { y, 0  }

   texture {
      pigment {
        colour Aquamarine
      }
      normal {
        waves 0.1
        frequency 800
        phase clock/20
      }
      finish {
        ambient 0.2*AMBIENT
        diffuse 0.1
        reflection 0.7
      }
      scale <1000.0, 1000.0, 1000.0>
   }
   no_shadow
}


#if clock >= CLOCK_LOGO_START

#declare SPACEX = 5.5
#declare SPACEY = 8
#declare SCALE = 1

union
{
	// Olivier lapicque
	object { char_O  scale SCALE translate <-6.6*SPACEX, 2*SPACEY, 0> }
	object { char_L  scale SCALE translate <-5.6*SPACEX, 2*SPACEY, 0> }
	object { char_I  scale SCALE translate <-4.9*SPACEX, 2*SPACEY, 0> }
	object { char_V  scale SCALE translate <-4.2*SPACEX, 2*SPACEY, 0> }
	object { char_I  scale SCALE translate <-3.6*SPACEX, 2*SPACEY, 0> }
	object { char_E  scale SCALE translate <-2.9*SPACEX, 2*SPACEY, 0> }
	object { char_R  scale SCALE translate <-1.9*SPACEX, 2*SPACEY, 0> }
	object { char_L  scale SCALE translate <0.1*SPACEX, 2*SPACEY, 0> }
	object { char_A  scale SCALE translate <1*SPACEX, 2*SPACEY, 0> }
	object { char_P  scale SCALE translate <2*SPACEX, 2*SPACEY, 0> }
	object { char_I  scale SCALE translate <2.7*SPACEX, 2*SPACEY, 0> }
	object { char_C  scale SCALE translate <3.4*SPACEX, 2*SPACEY, 0> }
	object { char_Q  scale SCALE translate <4.4*SPACEX, 2*SPACEY, 0> }
	object { char_U  scale SCALE translate <5.4*SPACEX, 2*SPACEY, 0> }
	object { char_E  scale SCALE translate <6.4*SPACEX, 2*SPACEY, 0> }
	// Jerome Hubert
	object { char_J  scale SCALE translate <-6.6*SPACEX, SPACEY, 0> }
	object { char_E  scale SCALE translate <-5.6*SPACEX, SPACEY, 0> }
	object { char_R  scale SCALE translate <-4.6*SPACEX, SPACEY, 0> }
	object { char_O  scale SCALE translate <-3.6*SPACEX, SPACEY, 0> }
	object { char_M  scale SCALE translate <-2.6*SPACEX, SPACEY, 0> }
	object { char_E  scale SCALE translate <-1.6*SPACEX, SPACEY, 0> }
	object { char_H  scale SCALE translate <1.4*SPACEX, SPACEY, 0> }
	object { char_U  scale SCALE translate <2.4*SPACEX, SPACEY, 0> }
	object { char_B  scale SCALE translate <3.4*SPACEX, SPACEY, 0> }
	object { char_E  scale SCALE translate <4.4*SPACEX, SPACEY, 0> }
	object { char_R  scale SCALE translate <5.4*SPACEX, SPACEY, 0> }
	object { char_T  scale SCALE translate <6.4*SPACEX, SPACEY, 0> }
	// EFREI 1996
	object { char_E  scale SCALE translate <-5.2*SPACEX, -SPACEY, 5> }
	object { char_F  scale SCALE translate <-4.2*SPACEX, -SPACEY, 5> }
	object { char_R  scale SCALE translate <-3.2*SPACEX, -SPACEY, 5> }
	object { char_E  scale SCALE translate <-2.2*SPACEX, -SPACEY, 5> }
	object { char_I  scale SCALE translate <-1.5*SPACEX, -SPACEY, 5> }
	object { char_1  scale SCALE translate <2*SPACEX, -SPACEY, 5> }
	object { char_9  scale SCALE translate <3*SPACEX, -SPACEY, 5> }
	object { char_9  scale SCALE translate <4*SPACEX, -SPACEY, 5> }
	object { char_6  scale SCALE translate <5*SPACEX, -SPACEY, 5> }
	pigment { White_Marble scale 4 }
	finish { ambient 0.9 diffuse 0 }
//	rotate -y*50
	translate <-10,15,30>
	no_shadow
}


#endif

